@@ -22,7 +22,6 @@ def read_sfh(byt_str):
         sfo = SFH_READ(byt_str[j*128: (j+1)*128])
         typ =  sfo.obj_type
         onam = str_byt.to_str(sfo.objnam.strip())
-        logger.debug('%d %s %d %s', j, onam, typ, sfdics.obj_name[typ])
         if typ == 1:
             sfo.diag()
             if n_obj == n_max:
@@ -72,7 +71,6 @@ class SFH_READ:
         """
         self.objnam   = str_byt.to_str(byte_str[0:8].strip())
         self.obj_type, self.level, self.status = unpack('>3H', byte_str[ 8: 14])
-        logger.debug('%s %d', self.objnam, self.obj_type)
         if self.obj_type in sfdics.obj_name.keys():
             self.object_type = sfdics.obj_name[self.obj_type]
         else:
@@ -111,7 +109,7 @@ class SFH_READ:
         self.data_format, self.acquseq, self.items, self.dev_type = unpack('>4H', self.val[:8])
         self.dev_addr, self.n_chan  = unpack('>2I', self.val[ 8: 16])
         self.task    , self.dev_num = unpack('>2H', self.val[16: 20])
-        self.n_steps                = unpack('>I', self.val[20: 24])[0]  
+        self.n_steps                = unpack('>I' , self.val[20: 24])[0]  
 
 
     def parmset(self):
