@@ -234,6 +234,12 @@ class SFREAD:
         if self.status:
             self.objects = [ lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type in [6, 7, 8, 13] ]
             self.parsets = [ lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type in [3, 4] ]
+        if 'ADDRLEN' in self.sfh.keys():
+            size_fac = sfdics.addrsizes[self.getaddrlen()]
+            for obj in self.sfh.keys():
+                if hasattr(self.sfh[obj], 'address'):
+                    self.sfh[obj].address *= size_fac
+                    self.sfh[obj].length *= size_fac
         self.cache = {}
 
 
@@ -298,6 +304,13 @@ class SFREAD:
                     return self.getobject(rel)
         return None
 
+    def getaddrlen(self):
+
+        sfo = self.sfh['ADDRLEN']
+        data = unpack('>H', sfo.val[:2])[0]
+        logger.debug('getaddrlen addr:%d, len:%d, data:%d', sfo.address, sfo.length, data)
+        logger.debug(sfo.descr)
+        return data
 
     def getobject(self, obj, cal=False, nbeg=None, nend=None):
         """
@@ -359,7 +372,8 @@ class SFREAD:
                 data = np.ndarray(shape_arr, '>%s' %sfmt, self.getchunk(addr, bytlen), order='F')
 
 # LongLong in [ns] and no zero at TS06
-            if otyp == 8 and dfmt == 13: # RMC:TIME-AD0
+            if otyp == 8 and dfmt == 13: # RMC:TIME-AD0, SXS:Time
+                logger.debug('Before getts06 dfmt:%d addr:%d len:%d data1:%d, %d', dfmt, addr, bytlen, data[0], data[1])
                 dout = 1e-9*(data - self.getts06())
             else:
                 dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
@@ -447,6 +461,7 @@ class SFREAD:
 
         pset = str_byt.to_str(pset)
         sfo = self.sfh[pset]
+        logger.debug('ParSet %s %d', pset, sfo.length)
         otyp = sfo.obj_type
         if otyp not in (3, 4):
             return None
@@ -462,7 +477,7 @@ class SFREAD:
             meta = type('', (), {})()
 #            meta.phys_unit = sfdics.unit_d[unit]
             meta.data_format = dfmt
-            logger.debug(pname, unit, dfmt, n_items)
+            logger.debug('%s %d %d %d', pname, unit, dfmt, n_items)
             status = unpack('>h', buf[j0+14:  j0+16])[0]
             j0 += 16
             if dfmt in sfdics.fmt2len.keys(): # char variable
@@ -484,7 +499,6 @@ class SFREAD:
                 dj0 = 8 * ( (bytlen + 7)//8 )
                 j0 += dj0
 
-            logger.debug(pname, data)
             par_d[pname] = sfobj.SFOBJ(data, sfho=meta)
 
         return par_d
@@ -557,6 +571,9 @@ class SFREAD:
         ts6 = 0
         for obj in self.parsets:
             if self.sfh[obj].obj_type == 3:
+                logger.debug('getts06 Dev:%s n_chan:%d', obj, self.sfh[obj].n_chan)
+                if self.sfh[obj].n_chan > 1: # git ???
+                    break
                 ps = self.getparset(obj)
                 if 'TS06' in ps.keys():
                     ts6 = ps['TS06']
@@ -564,7 +581,7 @@ class SFREAD:
 
         if ts6 == 0:
             ts6 = getcti_ts06(self.shot)
-
+        logger.debug('getts06 %d', ts6)
         return ts6
 
 
